@@ -56,8 +56,10 @@ Changelog
 0.0.51: add: add CORS support
 0.0.52: add: add PyScript demo
 0.0.53: fix: fix PyScript demo url
+0.0.54: fix: fix PyScript demo url
+0.0.55: add: add datasets.py
 """
 
 __title__ = "AKTools"
-__version__ = "0.0.53"
+__version__ = "0.0.55"
 __author__ = "AKFamily"
